// File SX52.H for CC1B

/**
 * \file SX52.H
 * \brief Definition file for SX52 chip
 *
 * This file must be the first file to include in a CC1B application for the SX52 chip.\n
 * It defines required settings for the CC1B compiler and defines constants for memory banks.
 *
 * \n
 * The following memory banks are available for the SX52 chip:
 *
 * - membank0  global ram  0x0A-0x0F\n
 * - membank1  banked ram 0x10-0x1F\n
 * - membank2  banked ram 0x20-0x2F\n
 * - membank3  banked ram 0x30-0x3F\n
 * - membank4  banked ram 0x40-0x4F\n
 * - membank5  banked ram 0x50-0x5F\n
 * - membank6  banked ram 0x60-0x6F\n
 * - membank7  banked ram 0x70-0x7F\n
 * - membank8  banked ram 0x80-0x8F\n
 * - membank9  banked ram 0x90-0x9F\n
 * - membank10 banked ram 0xA0-0xAF\n
 * - membank11 banked ram 0xB0-0xBF\n
 * - membank12 banked ram 0xC0-0xCF\n
 * - membank13 banked ram 0xD0-0xDF\n
 * - membank14 banked ram 0xE0-0xEF\n
 * - membank15 banked ram 0xF0-0xFF\n
 * - membank16 banked ram 0x00-0x0F (semi-direct addressing)
 *
 * \n
 * Use these constants in ##pragma statements to set the current rambank\n
 * eg. ##pragma membank1\n
 */

#pragma chip SX52, core 12 sx, code 4096, ram 10 : 0x10F
#pragma stackLevels 8 //make sure compiler uses 8 stacklevels for SX
#define _CHIP_SX52_
#define _CHIP_CODESIZE_ 0x1000
#define membank0 rambank -
#define membank1 rambank 1
#define membank2 rambank 2
#define membank3 rambank 3
#define membank4 rambank 4
#define membank5 rambank 5
#define membank6 rambank 6
#define membank7 rambank 7
#define membank8 rambank 8
#define membank9 rambank 9
#define membank10 rambank 10
#define membank11 rambank 11
#define membank12 rambank 12
#define membank13 rambank 13
#define membank14 rambank 14
#define membank15 rambank 15
#define membank16 rambank 0

/* RAM ADDRESS    BANKED  INDIRECT
   0x000 - 0x009  no      yes    : special purpose registers
   0x00A - 0x00F  no      yes    : unbanked RAM
   0x010 - 0x0FF  yes     yes    : RAM, bank 1 - 15 (16 byte each)
   0x100 - 0x10F  yes     no     : RAM, bank 0
*/

/* PREDEFINED:

  char W;
  char INDF, RTCC, PC, STATUS, FSR, RA, RB, RC, RD, RE;
  char INDF0, TMR0, PCL, PORTA, PORTB, PORTC, PORTD, PORTE; // optional
  char OPTION;

  STATUS :  bit Carry, DC, Zero_, PD, TO, PA0, PA1, PA2;

  char MODE;
  char DDRA, PLP_A, LVL_A;
  char DDRB, PLP_B, LVL_B, ST_B, WKEN_B, WKED_B, WKPND_B, CMP_B;
  char DDRC, PLP_C, LVL_C, ST_C;
  char DDRD, PLP_D, LVL_D, ST_D;
  char DDRE, PLP_E, LVL_E, ST_E;
  char TRISA, TRISB, TRISC, TRISD, TRISE; // optional

  char T1CPL, T1CPH, T1R2CML, T1R2CMH, T1R1CML, T1R1CMH;
  char T1CNTB, T1CNTA,
  char T2CPL, T2CPH, T2R2CML, T2R2CMH, T2R1CML, T2R1CMH;
  char T2CNTB, T2CNTA;
*/

// End of file SX52.H
